import React, { useMemo } from "react";
import FolderOpenIcon from "@material-ui/icons/FolderOpen";
import classnames from "classnames";
import { makeStyles } from "@material-ui/core/styles";
import Tooltip from "@material-ui/core/Tooltip";
var useStyles = makeStyles({
  label: {
    display: "inline-flex",
    cursor: "pointer",
    padding: 8,
    paddingLeft: 12,
    paddingRight: 12,
    margin: 4,
    borderRadius: 4,
    fontSize: 18,
    color: "#fff",
    alignItems: "center",
    "&:hover": {
      opacity: 0.6
    },
    "&.small": {
      fontSize: 12,
      fontWeight: "bold"
    }
  },
  deleteableIcon: {
    display: "inline-flex",
    cursor: "pointer",
    alignSelf: "center",
    fontSize: 11,
    width: 18,
    height: 18,
    alignItems: "center",
    justifyContent: "center",
    marginLeft: 4,
    borderRadius: 9,
    color: "#fff",
    backgroundColor: "rgba(0,0,0,0.2)"
  },
  hotkeyText: {
    paddingLeft: 4
  },
  tooltip: {
    whiteSpace: "pre-wrap"
  }
});

var Label = function Label(props) {
  var parent = props.parent,
      color = props.color,
      displayName = props.displayName,
      description = props.description,
      id = props.id,
      small = props.small,
      hasChildren = props.hasChildren,
      hotkey = props.hotkey,
      deletable = props.deletable;
  var classes = useStyles();
  var tooltipClasses = useMemo(function () {
    return {
      tooltip: classes.tooltip
    };
  }, [classes]);
  var button = /*#__PURE__*/React.createElement("div", {
    onClick: function onClick() {
      return props.onClick(id);
    },
    className: classnames(classes.label, small && "small"),
    style: {
      backgroundColor: color
    }
  }, hasChildren && /*#__PURE__*/React.createElement(FolderOpenIcon, {
    style: {
      width: small ? 12 : 20,
      height: small ? 12 : 20,
      marginRight: small ? 3 : 6
    }
  }), /*#__PURE__*/React.createElement("div", null, displayName || id), hotkey && /*#__PURE__*/React.createElement("div", {
    className: classes.hotkeyText
  }, "(", hotkey, ")"), deletable && /*#__PURE__*/React.createElement("div", {
    className: classes.deleteableIcon
  }, /*#__PURE__*/React.createElement("span", null, "\u2716")));

  if (description) {
    return /*#__PURE__*/React.createElement(Tooltip, {
      title: description,
      arrow: true,
      classes: tooltipClasses
    }, button);
  } else {
    return button;
  }
};

export default Label;